==> infima_client-0.45.0-py3-none-any.whl: infima_client/models/pool_attributes.py <==
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.issue_date import IssueDate
from ..models.maturity_date import MaturityDate
from ..models.pool_service_get_pools_response_200_poolattributes_agency_ticker import (
    PoolService_GetPoolsResponse_200PoolattributesAgencyTicker,
)
from ..models.pool_service_get_pools_response_200_poolattributes_agencybackingthepool import (
    PoolService_GetPoolsResponse_200PoolattributesAgencybackingthepool,
)
from ..models.pool_service_get_pools_response_200_poolattributes_coupon_type_fixarm import (
    PoolService_GetPoolsResponse_200PoolattributesCouponTypeFIXARM,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolAttributes")


@attr.s(auto_attribs=True)
class PoolAttributes:
    """ Pool attributes. """

    cusip: Union[Unset, str] = UNSET
    agency: Union[
        Unset, PoolService_GetPoolsResponse_200PoolattributesAgencybackingthepool
    ] = PoolService_GetPoolsResponse_200PoolattributesAgencybackingthepool.NULL_AGENCY
    agency_ticker: Union[
        Unset, PoolService_GetPoolsResponse_200PoolattributesAgencyTicker
    ] = PoolService_GetPoolsResponse_200PoolattributesAgencyTicker.NULL_AGENCY_TICKER
    coupon: Union[Unset, float] = UNSET
    coupon_type: Union[
        Unset, PoolService_GetPoolsResponse_200PoolattributesCouponTypeFIXARM
    ] = PoolService_GetPoolsResponse_200PoolattributesCouponTypeFIXARM.NULL_COUPON_TYPE
    factor: Union[Unset, float] = UNSET
    issue_date: Union[IssueDate, Unset] = UNSET
    maturity_date: Union[MaturityDate, Unset] = UNSET
    max_cs: Union[Unset, int] = UNSET
    max_ltv: Union[Unset, int] = UNSET
    max_ols: Union[Unset, float] = UNSET
    max_state: Union[Unset, str] = UNSET
    max_state_pct: Union[Unset, float] = UNSET
    min_ltv: Union[Unset, int] = UNSET
    num_loans_current: Union[Unset, int] = UNSET
    num_loans_origin: Union[Unset, int] = UNSET
    orig_wac: Union[Unset, float] = UNSET
    orig_wala: Union[Unset, int] = UNSET
    origin_issue_amount: Union[Unset, float] = UNSET
    pool_number: Union[Unset, str] = UNSET
    prefix: Union[Unset, str] = UNSET
    product: Union[Unset, str] = UNSET
    production_year: Union[Unset, int] = UNSET
    purch_pct: Union[Unset, float] = UNSET
    refi_pct: Union[Unset, float] = UNSET
    upb: Union[Unset, float] = UNSET
    wac: Union[Unset, float] = UNSET
    wala: Union[Unset, float] = UNSET
    waocs: Union[Unset, int] = UNSET
    waolsize: Union[Unset, float] = UNSET
    waoltv: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        cusip = self.cusip
        agency: Union[
            Unset, PoolService_GetPoolsResponse_200PoolattributesAgencybackingthepool
        ] = UNSET
        if not isinstance(self.agency, Unset):
            agency = self.agency

        agency_ticker: Union[
            Unset, PoolService_GetPoolsResponse_200PoolattributesAgencyTicker
        ] = UNSET
        if not isinstance(self.agency_ticker, Unset):
            agency_ticker = self.agency_ticker

        coupon = self.coupon
        coupon_type: Union[
            Unset, PoolService_GetPoolsResponse_200PoolattributesCouponTypeFIXARM
        ] = UNSET
        if not isinstance(self.coupon_type, Unset):
            coupon_type = self.coupon_type

        factor = self.factor
        issue_date: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.issue_date, Unset):
            issue_date = self.issue_date.to_dict()

        maturity_date: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.maturity_date, Unset):
            maturity_date = self.maturity_date.to_dict()

        max_cs = self.max_cs
        max_ltv = self.max_ltv
        max_ols = self.max_ols
        max_state = self.max_state
        max_state_pct = self.max_state_pct
        min_ltv = self.min_ltv
        num_loans_current = self.num_loans_current
        num_loans_origin = self.num_loans_origin
        orig_wac = self.orig_wac
        orig_wala = self.orig_wala
        origin_issue_amount = self.origin_issue_amount
        pool_number = self.pool_number
        prefix = self.prefix
        product = self.product
        production_year = self.production_year
        purch_pct = self.purch_pct
        refi_pct = self.refi_pct
        upb = self.upb
        wac = self.wac
        wala = self.wala
        waocs = self.waocs
        waolsize = self.waolsize
        waoltv = self.waoltv

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cusip is not UNSET:
            field_dict["CUSIP"] = cusip
        if agency is not UNSET:
            field_dict["agency"] = agency
        if agency_ticker is not UNSET:
            field_dict["agencyTicker"] = agency_ticker
        if coupon is not UNSET:
            field_dict["coupon"] = coupon
        if coupon_type is not UNSET:
            field_dict["couponType"] = coupon_type
        if factor is not UNSET:
            field_dict["factor"] = factor
        if issue_date is not UNSET:
            field_dict["issueDate"] = issue_date
        if maturity_date is not UNSET:
            field_dict["maturityDate"] = maturity_date
        if max_cs is not UNSET:
            field_dict["maxCs"] = max_cs
        if max_ltv is not UNSET:
            field_dict["maxLtv"] = max_ltv
        if max_ols is not UNSET:
            field_dict["maxOls"] = max_ols
        if max_state is not UNSET:
            field_dict["maxState"] = max_state
        if max_state_pct is not UNSET:
            field_dict["maxStatePct"] = max_state_pct
        if min_ltv is not UNSET:
            field_dict["minLtv"] = min_ltv
        if num_loans_current is not UNSET:
            field_dict["numLoansCurrent"] = num_loans_current
        if num_loans_origin is not UNSET:
            field_dict["numLoansOrigin"] = num_loans_origin
        if orig_wac is not UNSET:
            field_dict["origWac"] = orig_wac
        if orig_wala is not UNSET:
            field_dict["origWala"] = orig_wala
        if origin_issue_amount is not UNSET:
            field_dict["originIssueAmount"] = origin_issue_amount
        if pool_number is not UNSET:
            field_dict["poolNumber"] = pool_number
        if prefix is not UNSET:
            field_dict["prefix"] = prefix
        if product is not UNSET:
            field_dict["product"] = product
        if production_year is not UNSET:
            field_dict["productionYear"] = production_year
        if purch_pct is not UNSET:
            field_dict["purchPct"] = purch_pct
        if refi_pct is not UNSET:
            field_dict["refiPct"] = refi_pct
        if upb is not UNSET:
            field_dict["upb"] = upb
        if wac is not UNSET:
            field_dict["wac"] = wac
        if wala is not UNSET:
            field_dict["wala"] = wala
        if waocs is not UNSET:
            field_dict["waocs"] = waocs
        if waolsize is not UNSET:
            field_dict["waolsize"] = waolsize
        if waoltv is not UNSET:
            field_dict["waoltv"] = waoltv

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        cusip = d.pop("CUSIP", UNSET)

        agency = None
        _agency = d.pop("agency", UNSET)
        if _agency is not None and _agency is not UNSET:
            agency = PoolService_GetPoolsResponse_200PoolattributesAgencybackingthepool(
                _agency
            )

        agency_ticker = None
        _agency_ticker = d.pop("agencyTicker", UNSET)
        if _agency_ticker is not None and _agency_ticker is not UNSET:
            agency_ticker = PoolService_GetPoolsResponse_200PoolattributesAgencyTicker(
                _agency_ticker
            )

        coupon = d.pop("coupon", UNSET)

        coupon_type = None
        _coupon_type = d.pop("couponType", UNSET)
        if _coupon_type is not None and _coupon_type is not UNSET:
            coupon_type = (
                PoolService_GetPoolsResponse_200PoolattributesCouponTypeFIXARM(
                    _coupon_type
                )
            )

        factor = d.pop("factor", UNSET)

        issue_date: Union[IssueDate, Unset] = UNSET
        _issue_date = d.pop("issueDate", UNSET)
        if not isinstance(_issue_date, Unset):
            issue_date = IssueDate.from_dict(cast(Dict[str, Any], _issue_date))

        maturity_date: Union[MaturityDate, Unset] = UNSET
        _maturity_date = d.pop("maturityDate", UNSET)
        if not isinstance(_maturity_date, Unset):
            maturity_date = MaturityDate.from_dict(cast(Dict[str, Any], _maturity_date))

        max_cs = d.pop("maxCs", UNSET)

        max_ltv = d.pop("maxLtv", UNSET)

        max_ols = d.pop("maxOls", UNSET)

        max_state = d.pop("maxState", UNSET)

        max_state_pct = d.pop("maxStatePct", UNSET)

        min_ltv = d.pop("minLtv", UNSET)

        num_loans_current = d.pop("numLoansCurrent", UNSET)

        num_loans_origin = d.pop("numLoansOrigin", UNSET)

        orig_wac = d.pop("origWac", UNSET)

        orig_wala = d.pop("origWala", UNSET)

        origin_issue_amount = d.pop("originIssueAmount", UNSET)

        pool_number = d.pop("poolNumber", UNSET)

        prefix = d.pop("prefix", UNSET)

        product = d.pop("product", UNSET)

        production_year = d.pop("productionYear", UNSET)

        purch_pct = d.pop("purchPct", UNSET)

        refi_pct = d.pop("refiPct", UNSET)

        upb = d.pop("upb", UNSET)

        wac = d.pop("wac", UNSET)

        wala = d.pop("wala", UNSET)

        waocs = d.pop("waocs", UNSET)

        waolsize = d.pop("waolsize", UNSET)

        waoltv = d.pop("waoltv", UNSET)

        pool_attributes = cls(
            cusip=cusip,
            agency=agency,
            agency_ticker=agency_ticker,
            coupon=coupon,
            coupon_type=coupon_type,
            factor=factor,
            issue_date=issue_date,
            maturity_date=maturity_date,
            max_cs=max_cs,
            max_ltv=max_ltv,
            max_ols=max_ols,
            max_state=max_state,
            max_state_pct=max_state_pct,
            min_ltv=min_ltv,
            num_loans_current=num_loans_current,
            num_loans_origin=num_loans_origin,
            orig_wac=orig_wac,
            orig_wala=orig_wala,
            origin_issue_amount=origin_issue_amount,
            pool_number=pool_number,
            prefix=prefix,
            product=product,
            production_year=production_year,
            purch_pct=purch_pct,
            refi_pct=refi_pct,
            upb=upb,
            wac=wac,
            wala=wala,
            waocs=waocs,
            waolsize=waolsize,
            waoltv=waoltv,
        )

        pool_attributes.additional_properties = d
        return pool_attributes

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.59.0-py3-none-any.whl: infima_client/models/pool_attributes.py <==
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.issue_date import IssueDate
from ..models.maturity_date import MaturityDate
from ..models.pool_service_get_pools_response_200_poolattributes_agency import (
    PoolService_GetPoolsResponse_200PoolattributesAgency,
)
from ..models.pool_service_get_pools_response_200_poolattributes_agency_ticker import (
    PoolService_GetPoolsResponse_200PoolattributesAgencyTicker,
)
from ..models.pool_service_get_pools_response_200_poolattributes_coupon_type import (
    PoolService_GetPoolsResponse_200PoolattributesCouponType,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolAttributes")


@attr.s(auto_attribs=True)
class PoolAttributes:
    """ Pool attributes. """

    cusip: Union[Unset, str] = UNSET
    agency: Union[
        Unset, PoolService_GetPoolsResponse_200PoolattributesAgency
    ] = PoolService_GetPoolsResponse_200PoolattributesAgency.NULL_AGENCY
    agency_ticker: Union[
        Unset, PoolService_GetPoolsResponse_200PoolattributesAgencyTicker
    ] = PoolService_GetPoolsResponse_200PoolattributesAgencyTicker.NULL_AGENCY_TICKER
    coupon: Union[Unset, float] = UNSET
    coupon_type: Union[
        Unset, PoolService_GetPoolsResponse_200PoolattributesCouponType
    ] = PoolService_GetPoolsResponse_200PoolattributesCouponType.NULL_COUPON_TYPE
    factor: Union[Unset, float] = UNSET
    issue_date: Union[IssueDate, Unset] = UNSET
    maturity_date: Union[MaturityDate, Unset] = UNSET
    max_cs: Union[Unset, int] = UNSET
    max_ltv: Union[Unset, int] = UNSET
    max_ols: Union[Unset, float] = UNSET
    max_state: Union[Unset, str] = UNSET
    max_state_pct: Union[Unset, float] = UNSET
    min_ltv: Union[Unset, int] = UNSET
    num_loans_current: Union[Unset, int] = UNSET
    num_loans_origin: Union[Unset, int] = UNSET
    orig_wac: Union[Unset, float] = UNSET
    orig_wala: Union[Unset, int] = UNSET
    origin_issue_amount: Union[Unset, float] = UNSET
    pool_number: Union[Unset, str] = UNSET
    prefix: Union[Unset, str] = UNSET
    product: Union[Unset, str] = UNSET
    production_year: Union[Unset, int] = UNSET
    purch_pct: Union[Unset, float] = UNSET
    refi_pct: Union[Unset, float] = UNSET
    upb: Union[Unset, float] = UNSET
    wac: Union[Unset, float] = UNSET
    wala: Union[Unset, float] = UNSET
    waocs: Union[Unset, int] = UNSET
    waolsize: Union[Unset, float] = UNSET
    waoltv: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        cusip = self.cusip
        agency: Union[
            Unset, PoolService_GetPoolsResponse_200PoolattributesAgency
        ] = UNSET
        if not isinstance(self.agency, Unset):
            agency = self.agency

        agency_ticker: Union[
            Unset, PoolService_GetPoolsResponse_200PoolattributesAgencyTicker
        ] = UNSET
        if not isinstance(self.agency_ticker, Unset):
            agency_ticker = self.agency_ticker

        coupon = self.coupon
        coupon_type: Union[
            Unset, PoolService_GetPoolsResponse_200PoolattributesCouponType
        ] = UNSET
        if not isinstance(self.coupon_type, Unset):
            coupon_type = self.coupon_type

        factor = self.factor
        issue_date: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.issue_date, Unset):
            issue_date = self.issue_date.to_dict()

        maturity_date: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.maturity_date, Unset):
            maturity_date = self.maturity_date.to_dict()

        max_cs = self.max_cs
        max_ltv = self.max_ltv
        max_ols = self.max_ols
        max_state = self.max_state
        max_state_pct = self.max_state_pct
        min_ltv = self.min_ltv
        num_loans_current = self.num_loans_current
        num_loans_origin = self.num_loans_origin
        orig_wac = self.orig_wac
        orig_wala = self.orig_wala
        origin_issue_amount = self.origin_issue_amount
        pool_number = self.pool_number
        prefix = self.prefix
        product = self.product
        production_year = self.production_year
        purch_pct = self.purch_pct
        refi_pct = self.refi_pct
        upb = self.upb
        wac = self.wac
        wala = self.wala
        waocs = self.waocs
        waolsize = self.waolsize
        waoltv = self.waoltv

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cusip is not UNSET:
            field_dict["CUSIP"] = cusip
        if agency is not UNSET:
            field_dict["agency"] = agency
        if agency_ticker is not UNSET:
            field_dict["agencyTicker"] = agency_ticker
        if coupon is not UNSET:
            field_dict["coupon"] = coupon
        if coupon_type is not UNSET:
            field_dict["couponType"] = coupon_type
        if factor is not UNSET:
            field_dict["factor"] = factor
        if issue_date is not UNSET:
            field_dict["issueDate"] = issue_date
        if maturity_date is not UNSET:
            field_dict["maturityDate"] = maturity_date
        if max_cs is not UNSET:
            field_dict["maxCs"] = max_cs
        if max_ltv is not UNSET:
            field_dict["maxLtv"] = max_ltv
        if max_ols is not UNSET:
            field_dict["maxOls"] = max_ols
        if max_state is not UNSET:
            field_dict["maxState"] = max_state
        if max_state_pct is not UNSET:
            field_dict["maxStatePct"] = max_state_pct
        if min_ltv is not UNSET:
            field_dict["minLtv"] = min_ltv
        if num_loans_current is not UNSET:
            field_dict["numLoansCurrent"] = num_loans_current
        if num_loans_origin is not UNSET:
            field_dict["numLoansOrigin"] = num_loans_origin
        if orig_wac is not UNSET:
            field_dict["origWac"] = orig_wac
        if orig_wala is not UNSET:
            field_dict["origWala"] = orig_wala
        if origin_issue_amount is not UNSET:
            field_dict["originIssueAmount"] = origin_issue_amount
        if pool_number is not UNSET:
            field_dict["poolNumber"] = pool_number
        if prefix is not UNSET:
            field_dict["prefix"] = prefix
        if product is not UNSET:
            field_dict["product"] = product
        if production_year is not UNSET:
            field_dict["productionYear"] = production_year
        if purch_pct is not UNSET:
            field_dict["purchPct"] = purch_pct
        if refi_pct is not UNSET:
            field_dict["refiPct"] = refi_pct
        if upb is not UNSET:
            field_dict["upb"] = upb
        if wac is not UNSET:
            field_dict["wac"] = wac
        if wala is not UNSET:
            field_dict["wala"] = wala
        if waocs is not UNSET:
            field_dict["waocs"] = waocs
        if waolsize is not UNSET:
            field_dict["waolsize"] = waolsize
        if waoltv is not UNSET:
            field_dict["waoltv"] = waoltv

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        cusip = d.pop("CUSIP", UNSET)

        agency = None
        _agency = d.pop("agency", UNSET)
        if _agency is not None and _agency is not UNSET:
            agency = PoolService_GetPoolsResponse_200PoolattributesAgency(_agency)

        agency_ticker = None
        _agency_ticker = d.pop("agencyTicker", UNSET)
        if _agency_ticker is not None and _agency_ticker is not UNSET:
            agency_ticker = PoolService_GetPoolsResponse_200PoolattributesAgencyTicker(
                _agency_ticker
            )

        coupon = d.pop("coupon", UNSET)

        coupon_type = None
        _coupon_type = d.pop("couponType", UNSET)
        if _coupon_type is not None and _coupon_type is not UNSET:
            coupon_type = PoolService_GetPoolsResponse_200PoolattributesCouponType(
                _coupon_type
            )

        factor = d.pop("factor", UNSET)

        issue_date: Union[IssueDate, Unset] = UNSET
        _issue_date = d.pop("issueDate", UNSET)
        if not isinstance(_issue_date, Unset):
            issue_date = IssueDate.from_dict(cast(Dict[str, Any], _issue_date))

        maturity_date: Union[MaturityDate, Unset] = UNSET
        _maturity_date = d.pop("maturityDate", UNSET)
        if not isinstance(_maturity_date, Unset):
            maturity_date = MaturityDate.from_dict(cast(Dict[str, Any], _maturity_date))

        max_cs = d.pop("maxCs", UNSET)

        max_ltv = d.pop("maxLtv", UNSET)

        max_ols = d.pop("maxOls", UNSET)

        max_state = d.pop("maxState", UNSET)

        max_state_pct = d.pop("maxStatePct", UNSET)

        min_ltv = d.pop("minLtv", UNSET)

        num_loans_current = d.pop("numLoansCurrent", UNSET)

        num_loans_origin = d.pop("numLoansOrigin", UNSET)

        orig_wac = d.pop("origWac", UNSET)

        orig_wala = d.pop("origWala", UNSET)

        origin_issue_amount = d.pop("originIssueAmount", UNSET)

        pool_number = d.pop("poolNumber", UNSET)

        prefix = d.pop("prefix", UNSET)

        product = d.pop("product", UNSET)

        production_year = d.pop("productionYear", UNSET)

        purch_pct = d.pop("purchPct", UNSET)

        refi_pct = d.pop("refiPct", UNSET)

        upb = d.pop("upb", UNSET)

        wac = d.pop("wac", UNSET)

        wala = d.pop("wala", UNSET)

        waocs = d.pop("waocs", UNSET)

        waolsize = d.pop("waolsize", UNSET)

        waoltv = d.pop("waoltv", UNSET)

        pool_attributes = cls(
            cusip=cusip,
            agency=agency,
            agency_ticker=agency_ticker,
            coupon=coupon,
            coupon_type=coupon_type,
            factor=factor,
            issue_date=issue_date,
            maturity_date=maturity_date,
            max_cs=max_cs,
            max_ltv=max_ltv,
            max_ols=max_ols,
            max_state=max_state,
            max_state_pct=max_state_pct,
            min_ltv=min_ltv,
            num_loans_current=num_loans_current,
            num_loans_origin=num_loans_origin,
            orig_wac=orig_wac,
            orig_wala=orig_wala,
            origin_issue_amount=origin_issue_amount,
            pool_number=pool_number,
            prefix=prefix,
            product=product,
            production_year=production_year,
            purch_pct=purch_pct,
            refi_pct=refi_pct,
            upb=upb,
            wac=wac,
            wala=wala,
            waocs=waocs,
            waolsize=waolsize,
            waoltv=waoltv,
        )

        pool_attributes.additional_properties = d
        return pool_attributes

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
